# Changelog

## Version 0.4.0

- Support for compressed lists.

## Version 0.3.0

- Update to support the compressed genomicranges list implementation.

## Version 0.2.0

- chore: Remove Python 3.8 (EOL).
- Add support for Python 3.13.
- precommit: Replace docformatter with ruff's formatter.

## Version 0.1

- Initial Release
